#!/usr/bin/env python
# coding: utf-8

from setuptools import setup, find_packages

setup(
    name='Abhi_pdf',
    version='1.2',
    author='Tector Pro',
    description='Testing something',
    packages=find_packages()
)
